@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 from argparse import ArgumentParser
 
 from .. import VERSION_STRING
@@ -106,6 +109,16 @@ def build_parser_bw():
     # bw debug
     parser_debug = subparsers.add_parser("debug")
     parser_debug.set_defaults(func=bw_debug)
+    parser_debug.add_argument(
+        "-c",
+        "--command",
+        default=None,
+        dest='command',
+        metavar=_("COMMAND"),
+        required=False,
+        type=str,
+        help=_("command to execute in lieu of REPL"),
+    )
     parser_debug.add_argument(
         "-n",
         "--node",
@@ -385,7 +398,7 @@ def build_parser_bw():
         type=int,
     )
 
-    # bw repo test
+    # bw test
     parser_test = subparsers.add_parser("test")
     parser_test.set_defaults(func=bw_test)
     parser_test.add_argument(
@@ -396,6 +409,13 @@ def build_parser_bw():
         type=str,
         help=_("target nodes, groups and/or bundle selectors"),
     )
+    parser_test.add_argument(
+        "-c",
+        "--plugin-conflict-error",
+        action='store_true',
+        dest='plugin_conflict_error',
+        help=_("check for local modifications to files installed by plugins"),
+    )
     parser_test.add_argument(
         "-p",
         "--parallel-nodes",
