@@ -9,8 +9,8 @@ from ..utils.text import error_summary, red
 
 def bw_verify(repo, args):
     errors = []
-    target_nodes = get_target_nodes(repo, args.target)
-    with WorkerPool(workers=args.node_workers) as worker_pool:
+    pending_nodes = get_target_nodes(repo, args['target'])
+    with WorkerPool(workers=args['node_workers']) as worker_pool:
         while worker_pool.keep_running():
             try:
                 msg = worker_pool.get_event()
@@ -20,20 +20,20 @@ def bw_verify(repo, args):
                     e.task_id,
                     e.wrapped_exception,
                 )
-                if args.debug:
+                if args['debug']:
                     yield e.traceback
                 yield msg
                 errors.append(msg)
                 continue
             if msg['msg'] == 'REQUEST_WORK':
-                if target_nodes:
-                    node = target_nodes.pop()
+                if pending_nodes:
+                    node = pending_nodes.pop()
                     worker_pool.start_task(
                         msg['wid'],
                         node.verify,
                         task_id=node.name,
                         kwargs={
-                            'workers': args.item_workers,
+                            'workers': args['item_workers'],
                         },
                     )
                 else:
